# intake-thredds

| CI          | [![GitHub Workflow Status][github-ci-badge]][github-ci-link] [![Code Coverage Status][codecov-badge]][codecov-link] [![pre-commit.ci status][pre-commit.ci-badge]][pre-commit.ci-link] |
| :---------- | :------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------: |
| **Docs**    |                                                                     [![Documentation Status][rtd-badge]][rtd-link]                                                                     |
| **Package** |                                                          [![Conda][conda-badge]][conda-link] [![PyPI][pypi-badge]][pypi-link]                                                          |
| **License** |                                                                         [![License][license-badge]][repo-link]                                                                         |

Intake interface to [THREDDS](https://www.unidata.ucar.edu/software/tds/current/catalog/) data catalogs.

## Installation

Intake-thredds can be installed from PyPI with pip:

```bash
python -m pip install intake-thredds
```

Intake-thredds is also available from conda-forge for conda installations:

```bash
conda install -c conda-forge intake-thredds
```

See [documentation](https://intake-thredds.readthedocs.io) for more information.

[github-ci-badge]: https://github.com/intake/intake-thredds/actions/workflows/ci.yaml/badge.svg
[github-ci-link]: https://github.com/intake/intake-thredds/actions/workflows/ci.yaml
[codecov-badge]: https://img.shields.io/codecov/c/github/intake/intake-thredds.svg?logo=codecov
[codecov-link]: https://codecov.io/gh/intake/intake-thredds
[rtd-badge]: https://readthedocs.org/projects/intake-thredds/badge/?version=latest
[rtd-link]: https://intake-thredds.readthedocs.io/en/latest/?badge=latest
[pypi-badge]: https://img.shields.io/pypi/v/intake-thredds?logo=pypi
[pypi-link]: https://pypi.org/project/intake-thredds
[conda-badge]: https://img.shields.io/conda/vn/conda-forge/intake-thredds?logo=anaconda
[conda-link]: https://anaconda.org/conda-forge/intake-thredds
[license-badge]: https://img.shields.io/github/license/intake/intake-thredds
[repo-link]: https://github.com/intake/intake-thredds
[pre-commit.ci-badge]: https://results.pre-commit.ci/badge/github/intake/intake-thredds/main.svg
[pre-commit.ci-link]: https://results.pre-commit.ci/latest/github/intake/intake-thredds/main
